# Image Color Processor

Description. 
The package processing_images is used to:

	- Image reading
	- Image resize
	- Structural recognition
	- Histogram correspondence recognition
	- Ploting images
	- Ploting histograms
	- Image saving

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install processing_images

```bash
pip install processingImages
```

## Usage

```python
from processing_images.processing import combination, transformation
from processing_images.utils import io, plot
```

## Author
83Rafa

## License
[MIT](https://choosealicense.com/licenses/mit/)